@@ -1,14 +1,16 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
 
 def main():
     readFile=argv[1]
 
     try:
-	rowerFile=argv[2]
+        rowerFile=argv[2]
     except IndexError:
-	rowerFile="defaultrower.txt"
+        rowerFile="defaultrower.txt"
 
     rower=rowingdata.getrower(rowerFile)
 
@@ -19,10 +21,10 @@ def main():
     tcx.write_csv(file2)
 
     row=rowingdata.rowingdata(file2,rowtype="On-water",
-				rower=rower)
+                                rower=rower)
 
     row.uploadtoc2(rowerFile=rowerFile)
 
 
 
-    print("done "+readFile)
+    print(("done "+readFile))
